changeset 100379:41ff1c784cee

All callers to pmail-output-to-pmail-file changed to pmail-output-to-babyl-file.
author Chong Yidong <cyd@stupidchicken.com>
date Fri, 12 Dec 2008 15:26:46 +0000
parents 35a95343bc0c
children 5111bebfbd1c
files lisp/mail/pmail.el
diffstat 1 files changed, 8 insertions(+), 8 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/mail/pmail.el	Fri Dec 12 15:26:38 2008 +0000
+++ b/lisp/mail/pmail.el	Fri Dec 12 15:26:46 2008 +0000
@@ -600,7 +600,7 @@
   :type 'file
   :group 'pmail-files)
 (defcustom pmail-default-pmail-file "~/XMAIL"
-  "*Default file name for \\[pmail-output-to-pmail-file]."
+  "*Default file name for \\[pmail-output-to-babyl-file]."
   :type 'file
   :group 'pmail-files)
 (defcustom pmail-default-body-file "~/mailout"
@@ -987,7 +987,7 @@
   (define-key pmail-mode-map "n"      'pmail-next-undeleted-message)
   (define-key pmail-mode-map "\en"    'pmail-next-message)
   (define-key pmail-mode-map "\e\C-n" 'pmail-next-labeled-message)
-  (define-key pmail-mode-map "o"      'pmail-output-to-pmail-file)
+  (define-key pmail-mode-map "o"      'pmail-output-to-babyl-file)
   (define-key pmail-mode-map "\C-o"   'pmail-output)
   (define-key pmail-mode-map "p"      'pmail-previous-undeleted-message)
   (define-key pmail-mode-map "\ep"    'pmail-previous-message)
@@ -1038,7 +1038,7 @@
   '("Output (inbox)..." . pmail-output))
 
 (define-key pmail-mode-map [menu-bar classify output]
-  '("Output (Pmail)..." . pmail-output-to-pmail-file))
+  '("Output (Pmail)..." . pmail-output-to-babyl-file))
 
 (define-key pmail-mode-map [menu-bar classify kill-label]
   '("Kill Label..." . pmail-kill-label))
@@ -1206,7 +1206,7 @@
 \\[pmail-reply]	Reply to this message.  Like \\[pmail-mail] but initializes some fields.
 \\[pmail-retry-failure]	Send this message again.  Used on a mailer failure message.
 \\[pmail-forward]	Forward this message to another user.
-\\[pmail-output-to-pmail-file]       Output this message to an Pmail file (append it).
+\\[pmail-output-to-babyl-file]       Output this message to an Pmail file (append it).
 \\[pmail-output]	Output this message to a Unix-format mail file (append it).
 \\[pmail-output-body-to-file]	Save message body to a file.  Default filename comes from Subject line.
 \\[pmail-input]	Input Pmail file.  Run Pmail on that file.
@@ -1256,7 +1256,7 @@
   ;; because they contain no info except attribute changes
   ;; and deletion of messages.
   ;; The one exception is when messages are copied into an Pmail mode buffer.
   ;; pmail-output-to-pmail-file enables auto save when you do that.
   (setq buffer-auto-save-file-name nil)
   (setq mode-line-modified "--")
   (use-local-map pmail-mode-map)
@@ -1532,7 +1532,7 @@
 	    (cons "Output Pmail File"
 		  (pmail-list-to-menu "Output Pmail File"
 				      files
-				      'pmail-output-to-pmail-file))))
+				      'pmail-output-to-babyl-file))))
 
       (define-key pmail-mode-map [menu-bar classify input-menu]
 	'("Input Pmail File" . pmail-disable-menu))
@@ -2645,7 +2645,7 @@
 		(pmail-delete-forward)
 	      (if (string= "/dev/null" folder)
 		  (pmail-delete-message)
-		(pmail-output-to-pmail-file folder 1 t)
+		(pmail-output-to-babyl-file folder 1 t)
 		(setq d nil))))
 	(setq d (cdr d))))))
 
@@ -3799,7 +3799,7 @@
 TEXT and INDENT are not used."
   (speedbar-with-attached-buffer
    (message "Moving message to %s" token)
-   (pmail-output-to-pmail-file token)))
+   (pmail-output-to-babyl-file token)))
 
 ; Functions for setting, getting and encoding the POP password.
 ; The password is encoded to prevent it from being easily accessible
@@ -1256,7 +1256,7 @@
   ;; and deletion of messages.
   ;; The one exception is when messages are copied into an Pmail mode buffer.
-  ;; pmail-output-to-pmail-file enables auto save when you do that.
+  ;; pmail-output-to-babyl-file enables auto save when you do that.
   (setq buffer-auto-save-file-name nil)
   (setq mode-line-modified "--")